#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-DMdXXLXzmvwE6NFy8r0bq
key:                  hie-bios-0.12.0-DMdXXLXzmvwE6NFy8r0bq
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  ec11532cb4b9d07a524bf55397532ccb
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-DMdXXLXzmvwE6NFy8r0bq
depends:
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj base-4.18.2.1
    base16-bytestring-1.0.2.0-LOzdqrPOAmvA9dBRBt8wdk
    bytestring-0.11.5.3 co-log-core-0.3.2.6-C0JcN1wRLfF81giKIOzO0p
    conduit-1.3.6.1-7MjmOtU85HaB8wB7sCyBPV
    conduit-extra-1.3.8-J1pruM4XzBY6KaacrfmX7n
    cryptohash-sha1-0.11.101.0-4z9YPazGkkw2elIgzmGVb2 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 prettyprinter-1.7.2-HvkUgaUIGC1QRxB5LZpIj
    template-haskell-2.20.0.0 temporary-1.3-BCLEeiJZS9p2VFxBOmtDaG
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-9XJmvTTI62BHh5oKVcMeBg
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    yaml-0.11.11.2-7UoXYkKWr4r4oNCJDlnyxG

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

